@@ -7,10 +7,11 @@ import traceback
 import pandas_gbq as gbq
 from google.cloud import bigquery
 from google.oauth2.service_account import Credentials
+from trell.exceptions import BigQueryConnectionError, BigQueryDataFetchError, BigQueryGenericError
 
 from trell import config
-# from trell.utils import LogFormatter
-# LogFormatter.apply()
+from trell.utils import LogFormatter
+LogFormatter.apply()
 
 
 
@@ -20,8 +21,12 @@ class BigQuery:
     """BigQuery database utility functions"""
 
     def __init__(self,service_account_file_path=config.BIG_QUERY_SERVICE_ACCOUNT_FILE_PATH):
-        self.credentials = Credentials.from_service_account_file(service_account_file_path)
-        self.bq_client = bigquery.Client(credentials=self.credentials, project=self.credentials.project_id)
+
+        try:
+            self.credentials = Credentials.from_service_account_file(service_account_file_path)
+            self.bq_client = bigquery.Client(credentials=self.credentials, project=self.credentials.project_id)
+        except Exception as err:
+            raise BigQueryConnectionError(err)
 
     def get_data(self, query=None, query_config=None, max_retries=0, time_interval=5):
 
@@ -39,18 +44,20 @@ class BigQuery:
                 if query:
                     df = gbq.read_gbq(query=query, project_id=config.READ_BIG_QUERY_PROJECT,
                                     configuration=query_config, credentials=self.credentials)
+                    logging.debug("Data fetched successfully")
                     return df
                 else:
-                    return "Query is None"
-                flag = False
+                    raise Exception("Query is None")
+                flag = True
             except requests.exceptions.Timeout:
                 logging.info("readtimeot - - - - - - - - waiting for {} seconds".format(time_interval))
                 max_retries = max_retries - 1
                 flag = False if max_retries <= 0 else True
                 time.sleep(time_interval)
             except Exception as err:
-                logging.error(err)
-                logging.info(traceback.format_exc())
+                raise(BigQueryDataFetchError(err))
+                # logging.error(err)
+                # logging.info(traceback.format_exc())
                 flag = False
 
     def execute_query(self, query, query_config=None, max_retries=0, time_interval=5):
@@ -69,7 +76,7 @@ class BigQuery:
             try:
                 query_job = self.bq_client.query(query, job_config=query_config)  # API request
                 query_job.result(timeout=900)  # Waits for statement to finish
-                logging.info("------- Executed auery successfully ----- ")
+                logging.debug("------- Query Executed successfully ----- ")
                 flag = False
             except requests.exceptions.Timeout:
                 logging.info("readtimeot - - - - - - - - waiting for {} seconds".format(time_interval))
@@ -77,8 +84,7 @@ class BigQuery:
                 flag = False if max_retries <= 0 else True
                 time.sleep(time_interval)
             except Exception as err:
-                logging.error(err)
-                logging.info(traceback.format_exc())
+                raise BigQueryGenericError(err)
                 flag = False
 
 
@@ -97,8 +103,7 @@ class BigQuery:
                     credentials=self.credentials)
             print("Appending Done")
         except Exception as err:
-            logging.error(err)
-            logging.info(traceback.format_exc())
+            raise BigQueryGenericError(err)
 
 
 
@@ -118,8 +123,7 @@ class BigQuery:
             errors = self.bq_client.insert_rows_json(table, rows_to_insert)
             assert errors == []
         except Exception as err:
-            logging.error(err)
-            logging.info(traceback.format_exc())
+            raise BigQueryGenericError(err)
 
 
     def insert_rows_in_bigquery(self, dataset=None, table=None, rows_to_insert=None):
@@ -140,5 +144,4 @@ class BigQuery:
             else:
                 print("Failed adding rows", '\n', errors)
         except Exception as err:
-            logging.error(err)
-            logging.info(traceback.format_exc())
+            raise BigQueryGenericError(err)
