@@ -4,67 +4,87 @@ import pandas as pd
 from trell import aws
 import mysql.connector
 
-# from trell.utils import LogFormatter
-# LogFormatter.apply()
+from trell.exceptions import MysqlConnectionError, MysqlDataFetchError, MysqlGenericError
+from trell.utils import LogFormatter
+LogFormatter.apply()
  
 class MySQL:
 
     """MySQL database utility functions"""
 
+    def __init__(self, db_string):
+        """
+        initialisation method for mysql adapter
+        :param string db_string: mysql database connection string
+        """
+        self.db_string = db_string
+        
+
     @staticmethod
-    def get_data(query, db_string):
+    def get_data(query):
 
         """
         Fetch data from mysql as a dataframe.
         :param string query: query for fetching data from table
-        :param string db_string: mysql database connection string
         :return pd.DataFrame data
         """
+        try:
+            connection = sqlalchemy.create_engine(self.db_string)
+        except Exception as err:
+            raise MysqlConnectionError(err)
 
-        connection = sqlalchemy.create_engine(db_string)
         try:
             data = pd.read_sql(query + " ;", connection)
+            logging.debug("data fetched successfully")
             return data
         except Exception as err:
-            logging.error(err)
+            raise MysqlDataFetchError(err)
         finally:
             connection.dispose()
 
     @staticmethod
-    def execute_query(query, db_string):
+    def execute_query(query):
 
         """
         Execute a query in the mysql table
         :param string query: query for execution in the table
-        :param string db_string: mysql database connection string
         :return None
         """
 
-        connection = sqlalchemy.create_engine(db_string)
+        try:
+            connection = sqlalchemy.create_engine(self.db_string)
+        except Exception as err:
+            raise MysqlConnectionError(err)
+
         try:
             connection.execute(query)
+            logging.debug("query executed successfully")
         except Exception as err:
-            logging.error(err)
+            raise MysqlGenericError(err)
         finally:
             connection.dispose()
 
     @staticmethod
-    def dump_data(data, table_name, db_string, mode="append"):
+    def dump_data(data, table_name, mode="append"):
 
         """
         Execute a query in the mysql table
         :param string query: query for execution in the table
         :param string table_name: name of the the target table
-        :param string db_string: mysql database connection string
         :param string mode: it can be either replace or append
         :return None
         """
 
-        connection = sqlalchemy.create_engine(db_string)
+        try:
+            connection = sqlalchemy.create_engine(self.db_string)
+        except Exception as err:
+            raise MysqlConnectionError(err)
+
         try:
             data.to_sql(name=table_name, con=connection, if_exists=mode, index=False)
+            logging.debug("data dumped successfully")
         except Exception as err:
-            logging.error(err)
+            raise MysqlGenericError(err)
         finally:
             connection.dispose()
 
@@ -80,18 +100,22 @@ class MySQL:
         :return None
         """
 
-        connection = mysql.connector.connect(user=aws.cred['DATA_USER'],
-                                            password=aws.cred['DATA_PWD'],
-                                            host="127.0.0.1",
-                                            port=aws.cred['PORT_1'],
-                                            database="trellDb")
-        
-        connection = sqlalchemy.create_engine(aws.cred['LOCAL_PROD_DB_CONNECTION_STRING'])
+        try:
+            connection = mysql.connector.connect(user=aws.cred['DATA_USER'],
+                                                password=aws.cred['DATA_PWD'],
+                                                host="127.0.0.1",
+                                                port=aws.cred['PORT_1'],
+                                                database="trellDb")
+            
+            connection = sqlalchemy.create_engine(aws.cred['LOCAL_PROD_DB_CONNECTION_STRING'])
+        except Exception as err:
+            raise MysqlConnectionError(err)
+
         try:
             df = pd.read_sql(query + " ;", connection)
-            print("done")
+            logging.debug("data fetched successfully")
         except Exception as err:
-            logging.error(err)
+            raise MysqlDataFetchError(err)
         finally:
             # connection.close()       # for mysql.connector
             connection.dispose()   # for sqlalchemy
@@ -106,11 +130,16 @@ class MySQL:
         :return pd.DataFrame data
         """
 
-        connection = sqlalchemy.create_engine(aws.cred['DATA_PROD_DB_CONNECTION_STRING'])
+        try:
+            connection = sqlalchemy.create_engine(aws.cred['DATA_PROD_DB_CONNECTION_STRING'])
+        except Exception as err:
+            raise MysqlConnectionError(err)
+        
         try:
             return pd.read_sql(query + " ;", connection)
+            logging.debug("data fetched successfully")
         except Exception as err:
-            logging.error(err)
+            raise MysqlDataFetchError(err)
         finally:
             connection.dispose()
 
@@ -124,12 +153,16 @@ class MySQL:
         :return None
         """
 
-
-        connection = sqlalchemy.create_engine(aws.cred['DATA_PROD_DB_CONNECTION_STRING'])
+        try:
+            connection = sqlalchemy.create_engine(aws.cred['DATA_PROD_DB_CONNECTION_STRING'])
+        except Exception as err:
+            raise MysqlConnectionError(err)
+        
         try:
             connection.execute(query)
+            logging.debug("data executed successfully")
         except Exception as err:
-            logging.error(err)
+            raise MysqlGenericError(err)
         finally:
             connection.dispose()
 
@@ -145,11 +178,16 @@ class MySQL:
         :return None
         """
 
-        connection = sqlalchemy.create_engine(aws.cred['DATA_PROD_DB_CONNECTION_STRING'])
+        try:
+            connection = sqlalchemy.create_engine(aws.cred['DATA_PROD_DB_CONNECTION_STRING'])
+        except Exception as err:
+            raise MysqlConnectionError(err)
+        
         try:
             data.to_sql(name=table_name, con=connection, if_exists=mode, index=False)
+            logging.debug("data dumped successfully")
         except Exception as err:
-            logging.error(err)
+            raise MysqlGenericError(err)
         finally:
             connection.dispose()
 
