@@ -31,5 +31,5 @@ try:
 
     
 except Exception as err:
-    print("** you are not authorized to use Trell pip package **")
+    print("** --- you are not authorized to use Trell pip package --- **")
     print("Follow one of the folling steps to use Trell pip package \n 1. Setup AWS CLI \n 2. Place trell.env in the current folder \n 3. manually set up the credentials via \n    from trell_ai_util.utils import Credential \n    Credential.set(ACCESS_KEY='*****', SECRET_KEY='*****') ")
\ No newline at end of file
